aboutsummaryrefslogtreecommitdiffstats
path: root/src/gwin/gwin_list.h
diff options
context:
space:
mode:
authorinmarket <inmarket@ugfx.org>2017-01-09 11:40:48 +1000
committerinmarket <inmarket@ugfx.org>2017-01-09 11:40:48 +1000
commit0e00642bfca57432cc88adb7bbe029872804673f (patch)
tree9928076de9cb1bbf1afa36f87ecb9e05b9c37069 /src/gwin/gwin_list.h
parenta3241b9f39716a615452eab61a55a655ea67ed46 (diff)
downloaduGFX-0e00642bfca57432cc88adb7bbe029872804673f.tar.gz
uGFX-0e00642bfca57432cc88adb7bbe029872804673f.tar.bz2
uGFX-0e00642bfca57432cc88adb7bbe029872804673f.zip
Add gwinListItemSetText()
Diffstat (limited to 'src/gwin/gwin_list.h')
-rw-r--r--src/gwin/gwin_list.h16
1 files changed, 14 insertions, 2 deletions
diff --git a/src/gwin/gwin_list.h b/src/gwin/gwin_list.h
index a4d8aca7..81db7c34 100644
--- a/src/gwin/gwin_list.h
+++ b/src/gwin/gwin_list.h
@@ -169,14 +169,26 @@ void gwinListSetScroll(GHandle gh, scroll_t flag);
* reordered.
*
* @param[in] gh The widget handle (must be a list handle)
* @param[in] item The string which shall be displayed in the list afterwards
* @param[in] useAlloc If set to TRUE, the string will be dynamically allocated. A static buffer must be passed otherwise
*
* @return The current ID of the item. The ID might change if you remove items from the middle of the list
*
* @api
*/
-int gwinListAddItem(GHandle gh, const char* item, bool_t useAlloc);
+int gwinListAddItem(GHandle gh, const char* text, bool_t useAlloc);
+
+/**
+ * @brief Set the custom parameter of an item with a given ID
+ *
+ * @param[in] gh The widget handle (must be a list handle)
+ * @param[in] item The item ID
+ * @param[in] text The text to replace the existing text
+ * @param[in] useAlloc If set to TRUE, the string will be dynamically allocated. A static buffer must be passed otherwise
+ *
+ * @api
+ */
+void gwinListItemSetText(GHandle gh, int item, const char* text, bool_t useAlloc);
/**
* @brief Get the name behind an item with a given ID
@@ -169,14 +169,26 @@ void gwinListSetScroll(GHandle gh, scroll_t flag);
*
* @param[in] gh The widget handle (must be a list handle)
- * @param[in] item The string which shall be displayed in the list afterwards
+ * @param[in] text The string which shall be displayed in the list afterwards
* @param[in] useAlloc If set to TRUE, the string will be dynamically allocated. A static buffer must be passed otherwise
*